=======
History
=======

0.0.8 (2017-09-25)
------------------

* limit audio queue length, fix string to invalid filename

0.0.7 (2017-08-31)
------------------

* able to handle a few kind of connection failures and do reconnection

0.0.6 (2017-08-30)
------------------

* fix dueros oauth invalid access token issue
* fix dueros-auth

0.0.5 (2017-08-24)
------------------

* support alerts interface

0.0.4 (2017-07-13)
------------------

* add hands free alexa util using respeaker python library

0.0.3 (2017-07-11)
------------------

* use gstreamer to play audio stream
* support dueros avs compatible service
* many improments

0.0.2 (2017-07-05)
------------------

* rename alexa util to alexa-tap
* add oauth util alexa-auth

0.0.1 (2017-07-04)
------------------

* First release on PyPI.
